@@ -1,6 +1,7 @@
 # frozen_string_literal: true
 
-require "active_support/concern"
+# :markup: markdown
+
 require "active_support/core_ext/module/attribute_accessors_per_thread"
 
 module ActionText
@@ -8,12 +9,15 @@ module ActionText
     extend ActiveSupport::Concern
 
     included do
-      cattr_accessor :default_renderer, instance_accessor: false
       thread_cattr_accessor :renderer, instance_accessor: false
       delegate :render, to: :class
     end
 
     class_methods do
+      def action_controller_renderer
+        @action_controller_renderer ||= Class.new(ActionController::Base).renderer
+      end
+
       def with_renderer(renderer)
         previous_renderer = self.renderer
         self.renderer = renderer
@@ -23,7 +27,7 @@ module ActionText
       end
 
       def render(*args, &block)
-        (renderer || default_renderer).render_to_string(*args, &block)
+        (renderer || action_controller_renderer).render_to_string(*args, &block)
       end
     end
   end
