@@ -1,6 +1,10 @@
 class MessagesController < ActionController::Base
   before_action :set_message, only: [:show, :edit, :update, :destroy]
 
+  # This class intentionally does not extend ApplicationController, so the
+  # layout must be set manually. See commit 614e813 for details
+  layout "application"
+
   # GET /messages
   def index
     @messages = Message.all
@@ -53,6 +57,6 @@ class MessagesController < ActionController::Base
 
     # Only allow a trusted parameter list through.
     def message_params
-      params.require(:message).permit(:subject, :content)
+      params.expect(message: [:subject, :content])
     end
 end
