@@ -1,6 +1,7 @@
 # frozen_string_literal: true
 
 require "abstract_unit"
+require "active_support/core_ext/object/with"
 
 class FormTagHelperTest < ActionView::TestCase
   include RenderERBUtils
@@ -331,7 +332,7 @@ class FormTagHelperTest < ActionView::TestCase
   end
 
   def test_hidden_field_tag_default_omits_autocomplete
-    with_remove_hidden_field_autocomplete(true) do
+    ActionView::Base.with(remove_hidden_field_autocomplete: true) do
       actual = hidden_field_tag "id", 3
       expected = %(<input id="id" name="id" type="hidden" value="3" />)
       assert_dom_equal expected, actual
@@ -339,7 +340,7 @@ class FormTagHelperTest < ActionView::TestCase
   end
 
   def test_hidden_field_tag_legacy_includes_autocomplete_off
-    with_remove_hidden_field_autocomplete(false) do
+    ActionView::Base.with(remove_hidden_field_autocomplete: false) do
       actual = hidden_field_tag "id", 3
       expected = %(<input id="id" name="id" type="hidden" value="3" autocomplete="off" />)
       assert_dom_equal expected, actual
@@ -347,7 +348,7 @@ class FormTagHelperTest < ActionView::TestCase
   end
 
   def test_hidden_field_tag_respects_explicit_autocomplete_when_default_omits
-    with_remove_hidden_field_autocomplete(true) do
+    ActionView::Base.with(remove_hidden_field_autocomplete: true) do
       actual = hidden_field_tag "username", "me@example.com", autocomplete: "username"
       expected = %(<input id="username" name="username" type="hidden" value="me@example.com" autocomplete="username" />)
       assert_dom_equal expected, actual
@@ -355,7 +356,7 @@ class FormTagHelperTest < ActionView::TestCase
   end
 
   def test_hidden_field_tag_respects_explicit_autocomplete_when_legacy_includes_off
-    with_remove_hidden_field_autocomplete(false) do
+    ActionView::Base.with(remove_hidden_field_autocomplete: false) do
       actual = hidden_field_tag "username", "me@example.com", autocomplete: "username"
       expected = %(<input id="username" name="username" type="hidden" value="me@example.com" autocomplete="username" />)
       assert_dom_equal expected, actual
@@ -363,7 +364,7 @@ class FormTagHelperTest < ActionView::TestCase
   end
 
   def test_hidden_field_tag_with_autocomplete_false_in_legacy_mode
-    with_remove_hidden_field_autocomplete(false) do
+    ActionView::Base.with(remove_hidden_field_autocomplete: false) do
       actual = hidden_field_tag "id", 3, autocomplete: nil
       expected = %(<input id="id" name="id" type="hidden" value="3" />)
       assert_dom_equal expected, actual
@@ -371,7 +372,7 @@ class FormTagHelperTest < ActionView::TestCase
   end
 
   def test_form_tag_hidden_helpers_omit_autocomplete_by_default
-    with_remove_hidden_field_autocomplete(true) do
+    ActionView::Base.with(remove_hidden_field_autocomplete: true) do
       actual = form_tag({}, { method: :patch })
       expected = whole_form("http://www.example.com", method: :patch, no_autocomplete: true)
       assert_dom_equal expected, actual
@@ -379,7 +380,7 @@ class FormTagHelperTest < ActionView::TestCase
   end
 
   def test_form_tag_hidden_helpers_include_autocomplete_off_in_legacy_mode
-    with_remove_hidden_field_autocomplete(false) do
+    ActionView::Base.with(remove_hidden_field_autocomplete: false) do
       actual = form_tag({}, { method: :patch })
       expected = whole_form("http://www.example.com", method: :patch)
       assert_dom_equal expected, actual
@@ -1083,12 +1084,4 @@ class FormTagHelperTest < ActionView::TestCase
     ensure
       ActionView::Helpers::ContentExfiltrationPreventionHelper.prepend_content_exfiltration_prevention = old_value
     end
-
-    def with_remove_hidden_field_autocomplete(value)
-      old = ActionView::Base.remove_hidden_field_autocomplete
-      ActionView::Base.remove_hidden_field_autocomplete = value
-      yield
-    ensure
-      ActionView::Base.remove_hidden_field_autocomplete = old
-    end
 end
