@@ -67,8 +67,8 @@ class TestERBTemplate < ActiveSupport::TestCase
 
   def spot_highlight(compiled, highlight, first_column: nil, **options)
     # rindex by default since our tests usually put the highlight last
-    first_column ||= compiled.rindex(highlight) || 999
-    last_column = first_column + highlight.size
+    first_column ||= compiled.byterindex(highlight) || 999
+    last_column = first_column + highlight.bytesize
     spot = {
       first_column:, last_column:, snippet: compiled,
       first_lineno: 1, last_lineno: 1, script_lines: compiled.lines,
@@ -344,51 +344,35 @@ class TestERBTemplate < ActiveSupport::TestCase
     source = "<%= nomethoderror %>"
     compiled = "'.freeze; @output_buffer.append=  nomethoderror ; @output_buffer.safe_append='\n"
 
-    backtrace_location = Data.define(:lineno).new(lineno: 1)
     spot = spot_highlight(compiled, highlight)
     expected = spot_highlight(source, highlight, snippet: compiled)
 
-    assert_equal expected, new_template(source).translate_location(backtrace_location, spot)
+    assert_equal expected, new_template(source).translate_location(nil, spot)
   end
 
-  # merely tests for the case where the backtrace and spot disagree about lineno
-  def test_template_translate_location_lineno_offset
-    highlight = "nomethoderror"
-    source = "<%= nomethoderror %>"
-    compiled = "'.freeze; @output_buffer.append=  nomethoderror ; @output_buffer.safe_append='"
-
-    backtrace_location = Data.define(:lineno).new(lineno: 1)
-    spot = spot_highlight(compiled, highlight, first_lineno: 2, last_lineno: 2)
-    expected = spot_highlight(source, highlight, snippet: compiled)
-
-    assert_equal expected, new_template(source).translate_location(backtrace_location, spot)
-  end
-
-  # We are testing the failure case here. `find_offset` doesn't correctly handle the case
-  # where the line number is not the same in the backtrace and template.
   def test_template_translate_location_with_multiline_code_source
     highlight = "nomethoderror"
     source = "<%=\ngood(\n nomethoderror\n) %>"
     extracted_line = " nomethoderror\n"
-    compiled = "ValidatedOutputBuffer.wrap(@output_buffer, ({}), ' \ngood(\n nomethoderror\n" \
-               ") '.freeze, true).safe_none_append=( \ngood(\n nomethoderror\n) );\n@output_buffer"
+    compiled = "ValidatedOutputBuffer.wrap(@output_buffer, ({}), '\ngood(\n nomethoderror\n) '.freeze, true).safe_none_append=(\ngood(\n nomethoderror\n) );\n@output_buffer"
 
-    backtrace_location = Data.define(:lineno).new(lineno: 6)
     spot = spot_highlight(compiled, highlight, first_column: 1, first_lineno: 6, last_lineno: 6, snippet: extracted_line)
+    expected = spot_highlight(source, highlight, first_column: 1, first_lineno: 3, last_lineno: 3, snippet: extracted_line)
 
-    assert_equal spot, new_template(source).translate_location(backtrace_location, spot)
+    assert_equal expected, new_template(source).translate_location(nil, spot)
   end
 
-  def test_template_translate_location_with_multibye_string_before_highlight
-    highlight = "nomethoderror"
-    source = String.new("\u{a5}<%= nomethoderror %>", encoding: Encoding::UTF_8) # yen symbol
-    compiled = String.new("\u{a5}'.freeze; @output_buffer.append=  nomethoderror ; @output_buffer.safe_append='\n", encoding: Encoding::UTF_8)
+  def test_template_translate_location_with_multibyte_string_before_highlight
+    highlight = "nope"
+    # ensure the byte offset is enough to make us miss the highlight if wrong
+    multibyte = String.new("\u{a5}\u{a5}\u{a5}\u{a5}\u{a5}\u{a5}\u{a5}", encoding: Encoding::UTF_8) # yen symbol
+    source = "#{multibyte}<%= nope %>"
+    compiled = "#{multibyte}'.freeze; @output_buffer.append=  nope ; @output_buffer.safe_append='\n"
 
-    backtrace_location = Data.define(:lineno).new(lineno: 1)
     spot = spot_highlight(compiled, highlight)
     expected = spot_highlight(source, highlight, snippet: compiled)
 
-    assert_equal expected, new_template(source).translate_location(backtrace_location, spot)
+    assert_equal expected, new_template(source).translate_location(nil, spot)
   end
 
   def test_template_translate_location_no_match_in_compiled
@@ -396,10 +380,9 @@ class TestERBTemplate < ActiveSupport::TestCase
     source = "<%= nomatch %>"
     compiled = "this source does not contain the highlight, so the original spot is returned"
 
-    backtrace_location = Data.define(:lineno).new(lineno: 1)
     spot = spot_highlight(compiled, highlight, first_column: 50)
 
-    assert_equal spot, new_template(source).translate_location(backtrace_location, spot)
+    assert_equal spot, new_template(source).translate_location(nil, spot)
   end
 
   def test_template_translate_location_text_includes_highlight
@@ -407,11 +390,10 @@ class TestERBTemplate < ActiveSupport::TestCase
     source = " nomethoderror <%= nomethoderror %>"
     compiled = " nomethoderror '.freeze; @output_buffer.append=  nomethoderror ; @output_buffer.safe_append='\n"
 
-    backtrace_location = Data.define(:lineno).new(lineno: 1)
     spot = spot_highlight(compiled, highlight)
     expected = spot_highlight(source, highlight, snippet: compiled)
 
-    assert_equal expected, new_template(source).translate_location(backtrace_location, spot)
+    assert_equal expected, new_template(source).translate_location(nil, spot)
   end
 
   def test_template_translate_location_space_separated_erb_tags
@@ -419,11 +401,10 @@ class TestERBTemplate < ActiveSupport::TestCase
     source = "<%= goodcode %> <%= nomethoderror %>"
     compiled = "'.freeze; @output_buffer.append=  goodcode ; @output_buffer.safe_append=' '.freeze; @output_buffer.append=  nomethoderror ; @output_buffer.safe_append='\n"
 
-    backtrace_location = Data.define(:lineno).new(lineno: 1)
     spot = spot_highlight(compiled, highlight)
     expected = spot_highlight(source, highlight, snippet: compiled)
 
-    assert_equal expected, new_template(source).translate_location(backtrace_location, spot)
+    assert_equal expected, new_template(source).translate_location(nil, spot)
   end
 
   def test_template_translate_location_consecutive_erb_tags
@@ -431,11 +412,10 @@ class TestERBTemplate < ActiveSupport::TestCase
     source = "<%= goodcode %><%= nomethoderror %>"
     compiled = "'.freeze; @output_buffer.append=  goodcode ; @output_buffer.append=  nomethoderror ; @output_buffer.safe_append='\n"
 
-    backtrace_location = Data.define(:lineno).new(lineno: 1)
     spot = spot_highlight(compiled, highlight)
     expected = spot_highlight(source, highlight, snippet: compiled)
 
-    assert_equal expected, new_template(source).translate_location(backtrace_location, spot)
+    assert_equal expected, new_template(source).translate_location(nil, spot)
   end
 
   def test_template_translate_location_repeated_highlight_in_compiled_template
@@ -443,11 +423,10 @@ class TestERBTemplate < ActiveSupport::TestCase
     source = "<%= nomethoderror %>"
     compiled = "ValidatedOutputBuffer.wrap(@output_buffer, ({}), ' nomethoderror '.freeze, true).safe_none_append=  nomethoderror ; @output_buffer.safe_append='\n"
 
-    backtrace_location = Data.define(:lineno).new(lineno: 1)
     spot = spot_highlight(compiled, highlight)
     expected = spot_highlight(source, highlight, snippet: compiled)
 
-    assert_equal expected, new_template(source).translate_location(backtrace_location, spot)
+    assert_equal expected, new_template(source).translate_location(nil, spot)
   end
 
   def test_template_translate_location_flaky_pathological_template
@@ -455,10 +434,9 @@ class TestERBTemplate < ActiveSupport::TestCase
     source = "<%= flakymethod %> flakymethod <%= flakymethod " # fails on second call, no tailing %>
     compiled = "ValidatedOutputBuffer.wrap(@output_buffer, ({}), ' flakymethod '.freeze, true).safe_none_append=( flakymethod );@output_buffer.safe_append=' flakymethod '.freeze;ValidatedOutputBuffer.wrap(@output_buffer, ({}), ' flakymethod '.freeze, true).safe_none_append=( flakymethod "
 
-    backtrace_location = Data.define(:lineno).new(lineno: 1)
     spot = spot_highlight(compiled, highlight)
     expected = spot_highlight(source, highlight, snippet: compiled)
 
-    assert_equal expected, new_template(source).translate_location(backtrace_location, spot)
+    assert_equal expected, new_template(source).translate_location(nil, spot)
   end
 end
