@@ -417,12 +417,13 @@ module ActionView
   end
 
   class HTMLParserTest < ActionView::TestCase
-    test "rendered.html is a Nokogiri::XML::Element" do
+    test "rendered.html is a Nokogiri::XML::DocumentFragment" do
       developer = DeveloperStruct.new("Eloy")
 
       render "developers/developer", developer: developer
 
-      assert_kind_of Nokogiri::XML::Element, rendered.html
+      assert_kind_of Nokogiri::XML::DocumentFragment, rendered.html
+      assert_equal rendered.to_s, rendered.html.to_s
       assert_equal developer.name, document_root_element.text
     end
 
@@ -445,6 +446,7 @@ module ActionView
       render formats: :json, partial: "developers/developer", locals: { developer: developer }
 
       assert_kind_of ActiveSupport::HashWithIndifferentAccess, rendered.json
+      assert_equal rendered.to_s, rendered.json.to_json
       assert_equal developer.name, rendered.json[:name]
     end
   end
@@ -474,8 +476,33 @@ module ActionView
       assert @called_initialize
     end
   end
-end
 
-if RUBY_VERSION >= "3.1"
-  require_relative "./test_case_test/pattern_matching_test_cases"
+  class PatternMatchingTestCases < ActionView::TestCase
+    test "document_root_element integrates with pattern matching" do
+      developer = DeveloperStruct.new("Eloy")
+
+      render "developers/developer_with_h1", developer: developer
+
+      assert_pattern { document_root_element.at("h1") => { content: "Eloy", attributes: [{ name: "id", value: "name" }] } }
+      refute_pattern { document_root_element.at("h1") => { content: "Not Eloy" } }
+    end
+
+    test "rendered.html integrates with pattern matching" do
+      developer = DeveloperStruct.new("Eloy")
+
+      render "developers/developer", developer: developer
+
+      assert_pattern { rendered.html => { content: "Eloy" } }
+      refute_pattern { rendered.html => { content: "Not Eloy" } }
+    end
+
+    test "rendered.json integrates with pattern matching" do
+      developer = DeveloperStruct.new("Eloy")
+
+      render formats: :json, partial: "developers/developer", locals: { developer: developer }
+
+      assert_pattern { rendered.json => { name: "Eloy" } }
+      refute_pattern { rendered.json => { name: "Not Eloy" } }
+    end
+  end
 end
