@@ -35,10 +35,9 @@ class ArgumentSerializationTest < ActiveSupport::TestCase
       MyString.new(hash["value"])
     end
 
-    private
-      def klass
-        MyString
-      end
+    def klass
+      MyString
+    end
   end
 
   class StringWithoutSerializer < String
@@ -46,10 +45,15 @@ class ArgumentSerializationTest < ActiveSupport::TestCase
 
   setup do
     @person = Person.find("5")
+    @original_serializers = ActiveJob::Serializers.serializers
+  end
+
+  teardown do
+    ActiveJob::Serializers.serializers = @original_serializers
   end
 
   [ nil, 1, 1.0, 1_000_000_000_000_000_000_000,
-    "a", true, false,
+    "a", true, false, BigDecimal(5),
     :a,
     1.day,
     Date.new(2001, 2, 3),
@@ -80,28 +84,6 @@ class ArgumentSerializationTest < ActiveSupport::TestCase
     end
   end
 
-  test "dangerously treats BigDecimal arguments as primitives not requiring serialization by default" do
-    assert_deprecated(<<~MSG.chomp, ActiveJob.deprecator) do
-      Primitive serialization of BigDecimal job arguments is deprecated as it may serialize via .to_s using certain queue adapters.
-      Enable config.active_job.use_big_decimal_serializer to use BigDecimalSerializer instead, which will be mandatory in Rails 7.2.
-
-      Note that if your application has multiple replicas, you should only enable this setting after successfully deploying your app to Rails 7.1 first.
-      This will ensure that during your deployment all replicas are capable of deserializing arguments serialized with BigDecimalSerializer.
-    MSG
-      assert_equal(
-        BigDecimal(5),
-        *ActiveJob::Arguments.deserialize(ActiveJob::Arguments.serialize([BigDecimal(5)])),
-      )
-    end
-  end
-
-  test "safely serializes BigDecimal arguments if configured to use_big_decimal_serializer" do
-    # BigDecimal(5) example should be moved back up into array above in Rails 7.2
-    with_big_decimal_serializer do
-      assert_arguments_unchanged BigDecimal(5)
-    end
-  end
-
   [ Object.new, Person.find("5").to_gid, Class.new ].each do |arg|
     test "does not serialize #{arg.class}" do
       assert_raises ActiveJob::SerializationError do
@@ -132,6 +114,8 @@ class ArgumentSerializationTest < ActiveSupport::TestCase
   end
 
   test "serialize a ActionController::Parameters" do
+    ActiveJob::Serializers.add_serializers ActiveJob::Serializers::ActionControllerParametersSerializer
+
     parameters = Parameters.new(a: 1)
 
     assert_equal(
@@ -155,7 +139,7 @@ class ArgumentSerializationTest < ActiveSupport::TestCase
     assert_instance_of MyString, deserialized
     assert_equal my_string, deserialized
   ensure
-    ActiveJob::Serializers._additional_serializers = original_serializers
+    ActiveJob::Serializers.serializers = original_serializers
   end
 
   test "serialize a String subclass object without a serializer" do
@@ -296,12 +280,4 @@ class ArgumentSerializationTest < ActiveSupport::TestCase
 
       JobBuffer.last_value
     end
-
-    def with_big_decimal_serializer(temporary = true)
-      original = ActiveJob.use_big_decimal_serializer
-      ActiveJob.use_big_decimal_serializer = temporary
-      yield
-    ensure
-      ActiveJob.use_big_decimal_serializer = original
-    end
 end
