@@ -18,7 +18,7 @@ module ActiveRecord
   # For example the following migration is not reversible.
   # Rolling back this migration will raise an ActiveRecord::IrreversibleMigration error.
   #
-  #   class IrreversibleMigrationExample < ActiveRecord::Migration[8.0]
+  #   class IrreversibleMigrationExample < ActiveRecord::Migration[8.1]
   #     def change
   #       create_table :distributors do |t|
   #         t.string :zipcode
@@ -36,7 +36,7 @@ module ActiveRecord
   #
   # 1. Define <tt>#up</tt> and <tt>#down</tt> methods instead of <tt>#change</tt>:
   #
-  #  class ReversibleMigrationExample < ActiveRecord::Migration[8.0]
+  #  class ReversibleMigrationExample < ActiveRecord::Migration[8.1]
   #    def up
   #      create_table :distributors do |t|
   #        t.string :zipcode
@@ -61,7 +61,7 @@ module ActiveRecord
   #
   # 2. Use the #reversible method in <tt>#change</tt> method:
   #
-  #   class ReversibleMigrationExample < ActiveRecord::Migration[8.0]
+  #   class ReversibleMigrationExample < ActiveRecord::Migration[8.1]
   #     def change
   #       create_table :distributors do |t|
   #         t.string :zipcode
@@ -246,7 +246,7 @@ module ActiveRecord
   #
   # Example of a simple migration:
   #
-  #   class AddSsl < ActiveRecord::Migration[8.0]
+  #   class AddSsl < ActiveRecord::Migration[8.1]
   #     def up
   #       add_column :accounts, :ssl_enabled, :boolean, default: true
   #     end
@@ -266,7 +266,7 @@ module ActiveRecord
   #
   # Example of a more complex migration that also needs to initialize data:
   #
-  #   class AddSystemSettings < ActiveRecord::Migration[8.0]
+  #   class AddSystemSettings < ActiveRecord::Migration[8.1]
   #     def up
   #       create_table :system_settings do |t|
   #         t.string  :name
@@ -395,7 +395,7 @@ module ActiveRecord
   #   $ bin/rails generate migration add_fieldname_to_tablename fieldname:string
   #
   # This will generate the file <tt>timestamp_add_fieldname_to_tablename.rb</tt>, which will look like this:
-  #   class AddFieldnameToTablename < ActiveRecord::Migration[8.0]
+  #   class AddFieldnameToTablename < ActiveRecord::Migration[8.1]
   #     def change
   #       add_column :tablenames, :fieldname, :string
   #     end
@@ -421,7 +421,7 @@ module ActiveRecord
   #
   # Not all migrations change the schema. Some just fix the data:
   #
-  #   class RemoveEmptyTags < ActiveRecord::Migration[8.0]
+  #   class RemoveEmptyTags < ActiveRecord::Migration[8.1]
   #     def up
   #       Tag.all.each { |tag| tag.destroy if tag.pages.empty? }
   #     end
@@ -434,7 +434,7 @@ module ActiveRecord
   #
   # Others remove columns when they migrate up instead of down:
   #
-  #   class RemoveUnnecessaryItemAttributes < ActiveRecord::Migration[8.0]
+  #   class RemoveUnnecessaryItemAttributes < ActiveRecord::Migration[8.1]
   #     def up
   #       remove_column :items, :incomplete_items_count
   #       remove_column :items, :completed_items_count
@@ -448,7 +448,7 @@ module ActiveRecord
   #
   # And sometimes you need to do something in SQL not abstracted directly by migrations:
   #
-  #   class MakeJoinUnique < ActiveRecord::Migration[8.0]
+  #   class MakeJoinUnique < ActiveRecord::Migration[8.1]
   #     def up
   #       execute "ALTER TABLE `pages_linked_pages` ADD UNIQUE `page_id_linked_page_id` (`page_id`,`linked_page_id`)"
   #     end
@@ -465,7 +465,7 @@ module ActiveRecord
   # <tt>Base#reset_column_information</tt> in order to ensure that the model has the
   # latest column data from after the new column was added. Example:
   #
-  #   class AddPeopleSalary < ActiveRecord::Migration[8.0]
+  #   class AddPeopleSalary < ActiveRecord::Migration[8.1]
   #     def up
   #       add_column :people, :salary, :integer
   #       Person.reset_column_information
@@ -527,7 +527,7 @@ module ActiveRecord
   # To define a reversible migration, define the +change+ method in your
   # migration like this:
   #
-  #   class TenderloveMigration < ActiveRecord::Migration[8.0]
+  #   class TenderloveMigration < ActiveRecord::Migration[8.1]
   #     def change
   #       create_table(:horses) do |t|
   #         t.column :content, :text
@@ -557,7 +557,7 @@ module ActiveRecord
   # can't execute inside a transaction though, and for these situations
   # you can turn the automatic transactions off.
   #
-  #   class ChangeEnum < ActiveRecord::Migration[8.0]
+  #   class ChangeEnum < ActiveRecord::Migration[8.1]
   #     disable_ddl_transaction!
   #
   #     def up
@@ -570,6 +570,7 @@ module ActiveRecord
   class Migration
     autoload :CommandRecorder, "active_record/migration/command_recorder"
     autoload :Compatibility, "active_record/migration/compatibility"
+    autoload :DefaultSchemaVersionsFormatter, "active_record/migration/default_schema_versions_formatter"
     autoload :JoinTable, "active_record/migration/join_table"
     autoload :ExecutionStrategy, "active_record/migration/execution_strategy"
     autoload :DefaultStrategy, "active_record/migration/default_strategy"
@@ -781,6 +782,11 @@ module ActiveRecord
             system("bin/rails db:test:prepare")
           end
         end
+
+        def respond_to_missing?(method, include_private = false)
+          return false if nearest_delegate == delegate
+          nearest_delegate.respond_to?(method, include_private)
+        end
     end
 
     def disable_ddl_transaction # :nodoc:
@@ -818,7 +824,7 @@ module ActiveRecord
     # and create the table 'apples' on the way up, and the reverse
     # on the way down.
     #
-    #   class FixTLMigration < ActiveRecord::Migration[8.0]
+    #   class FixTLMigration < ActiveRecord::Migration[8.1]
     #     def change
     #       revert do
     #         create_table(:horses) do |t|
@@ -837,7 +843,7 @@ module ActiveRecord
     #
     #   require_relative "20121212123456_tenderlove_migration"
     #
-    #   class FixupTLMigration < ActiveRecord::Migration[8.0]
+    #   class FixupTLMigration < ActiveRecord::Migration[8.1]
     #     def change
     #       revert TenderloveMigration
     #
@@ -888,7 +894,7 @@ module ActiveRecord
     # when the three columns 'first_name', 'last_name' and 'full_name' exist,
     # even when migrating down:
     #
-    #    class SplitNameMigration < ActiveRecord::Migration[8.0]
+    #    class SplitNameMigration < ActiveRecord::Migration[8.1]
     #      def change
     #        add_column :users, :first_name, :string
     #        add_column :users, :last_name, :string
@@ -916,7 +922,7 @@ module ActiveRecord
     # In the following example, the new column +published+ will be given
     # the value +true+ for all existing records.
     #
-    #    class AddPublishedToPosts < ActiveRecord::Migration[8.0]
+    #    class AddPublishedToPosts < ActiveRecord::Migration[8.1]
     #      def change
     #        add_column :posts, :published, :boolean, default: false
     #        up_only do
@@ -1169,6 +1175,10 @@ module ActiveRecord
       def command_recorder
         CommandRecorder.new(connection)
       end
+
+      def respond_to_missing?(method, include_private = false)
+        execution_strategy.respond_to?(method, include_private) || super
+      end
   end
 
   # MigrationProxy is used to defer loading of the actual migration classes
