@@ -493,6 +493,15 @@ class EnumTest < ActiveRecord::TestCase
 
     assert_match(/must not contain a blank name\.$/, e.message)
 
+    e = assert_raises(ArgumentError) do
+      Class.new(ActiveRecord::Base) do
+        self.table_name = "books"
+        enum :status, { proposed: Object.new, active: :active }
+      end
+    end
+
+    assert_match(/must be only booleans, integers, symbols or strings/, e.message)
+
     e = assert_raises(ArgumentError) do
       Class.new(ActiveRecord::Base) do
         self.table_name = "books"
@@ -575,6 +584,22 @@ class EnumTest < ActiveRecord::TestCase
     end
   end
 
+  test "conflict message grammar" do
+    conflicts = {
+      column: /will generate a class method/,
+      logger: /will generate an instance method/,
+    }
+
+    conflicts.each do |name, pattern|
+      assert_raises(ArgumentError, match: pattern) do
+        Class.new(ActiveRecord::Base) do
+          self.table_name = "books"
+          enum name, [:value]
+        end
+      end
+    end
+  end
+
   test "overriding enum method should not raise" do
     assert_nothing_raised do
       Class.new(ActiveRecord::Base) do
@@ -715,6 +740,12 @@ class EnumTest < ActiveRecord::TestCase
     assert_equal "proposed", book.aliased_status
   end
 
+  test "enum with a hash with symbol values" do
+    book = Book.create!(symbol_status: :proposed)
+    assert_equal "proposed", book.symbol_status
+    assert_predicate book, :symbol_status_proposed?
+  end
+
   test "query state by predicate with prefix" do
     assert_predicate @book, :author_visibility_visible?
     assert_not_predicate @book, :author_visibility_invisible?
@@ -907,6 +938,7 @@ class EnumTest < ActiveRecord::TestCase
     klass = Class.new(ActiveRecord::Base) do
       self.table_name = "books"
       enum :status, default: 0, scopes: 1, prefix: 2, suffix: 3
+      enum :last_read, { default: 0, scopes: 1, prefix: 2, suffix: 3 }, prefix: "p", suffix: true
     end
 
     book = klass.new
@@ -914,6 +946,11 @@ class EnumTest < ActiveRecord::TestCase
     assert_not_predicate book, :scopes?
     assert_not_predicate book, :prefix?
     assert_not_predicate book, :suffix?
+
+    assert_predicate book, :p_default_last_read?
+    assert_not_predicate book, :p_scopes_last_read?
+    assert_not_predicate book, :p_prefix_last_read?
+    assert_not_predicate book, :p_suffix_last_read?
   end
 
   test "scopes are named like methods" do
