@@ -8,8 +8,12 @@ class ErrorsTest < ActiveRecord::TestCase
     base = ActiveRecord::ActiveRecordError
     error_klasses = ObjectSpace.each_object(Class).select { |klass| klass < base }
 
+    expected_to_be_initializable_with_no_args = error_klasses - [
+      ActiveRecord::AmbiguousSourceReflectionForThroughAssociation,
+      ActiveRecord::DeprecatedAssociationError
+    ]
     assert_nothing_raised do
-      (error_klasses - [ActiveRecord::AmbiguousSourceReflectionForThroughAssociation]).each do |error_klass|
+      expected_to_be_initializable_with_no_args.each do |error_klass|
         error_klass.new.inspect
       rescue ArgumentError
         raise "Instance of #{error_klass} can't be initialized with no arguments"
