@@ -9,7 +9,7 @@ module ActiveRecord
 
       def setup
         super
-        @connection = ActiveRecord::Base.connection
+        @connection = ActiveRecord::Base.lease_connection
         @table_name = :testings
 
         connection.create_table table_name do |t|
@@ -53,7 +53,7 @@ module ActiveRecord
         e = assert_raises(ArgumentError) {
           connection.rename_index(table_name, "old_idx", too_long_index_name)
         }
-        assert_match(/too long; the limit is #{connection.index_name_length} characters/, e.message)
+        assert_match(/too long \(#{too_long_index_name.length} characters\); the limit is #{connection.index_name_length} characters/, e.message)
 
         assert connection.index_name_exists?(table_name, "old_idx")
       end
@@ -75,7 +75,7 @@ module ActiveRecord
         e = assert_raises(ArgumentError) {
           connection.add_index(table_name, "foo", name: too_long_index_name)
         }
-        assert_match(/too long; the limit is #{connection.index_name_length} characters/, e.message)
+        assert_match(/too long \(#{too_long_index_name.length} characters\); the limit is #{connection.index_name_length} characters/, e.message)
 
         assert_not connection.index_name_exists?(table_name, too_long_index_name)
         connection.add_index(table_name, "foo", name: good_index_name)
@@ -178,6 +178,7 @@ module ActiveRecord
         connection.add_index :testings, [:foo, :bar], name: "my_index"
         assert connection.index_exists?(:testings, [:foo, :bar], name: "my_index")
         assert connection.index_exists?(:testings, [], name: "my_index")
+        assert connection.index_exists?(:testings, name: "my_index")
         assert_not connection.index_exists?(:testings, [:foo], name: "my_index")
       end
 
@@ -220,7 +221,9 @@ module ActiveRecord
 
       def test_add_index
         connection.add_index("testings", "last_name")
+        assert connection.index_exists?("testings", "last_name")
         connection.remove_index("testings", "last_name")
+        assert_not connection.index_exists?("testings", "last_name")
 
         connection.add_index("testings", ["last_name", "first_name"])
         connection.remove_index("testings", column: ["last_name", "first_name"])
@@ -254,70 +257,82 @@ module ActiveRecord
         connection.add_index("testings", %w(last_name first_name administrator), name: "named_admin")
         connection.remove_index("testings", name: "named_admin")
 
-        # Selected adapters support index sort order
-        if current_adapter?(:SQLite3Adapter, :Mysql2Adapter, :TrilogyAdapter, :PostgreSQLAdapter)
-          connection.add_index("testings", ["last_name"], order: { last_name: :desc })
-          connection.remove_index("testings", ["last_name"])
-          connection.add_index("testings", ["last_name", "first_name"], order: { last_name: :desc })
-          connection.remove_index("testings", ["last_name", "first_name"])
-          connection.add_index("testings", ["last_name", "first_name"], order: { last_name: :desc, first_name: :asc })
-          connection.remove_index("testings", ["last_name", "first_name"])
-          connection.add_index("testings", ["last_name", "first_name"], order: :desc)
-          connection.remove_index("testings", ["last_name", "first_name"])
-        end
+        connection.add_index("testings", ["last_name"], order: { last_name: :desc })
+        connection.remove_index("testings", ["last_name"])
+        connection.add_index("testings", ["last_name", "first_name"], order: { last_name: :desc })
+        connection.remove_index("testings", ["last_name", "first_name"])
+        connection.add_index("testings", ["last_name", "first_name"], order: { last_name: :desc, first_name: :asc })
+        connection.remove_index("testings", ["last_name", "first_name"])
+        connection.add_index("testings", ["last_name", "first_name"], order: :desc)
+        connection.remove_index("testings", ["last_name", "first_name"])
       end
 
-      if current_adapter?(:PostgreSQLAdapter)
-        def test_add_partial_index
-          connection.add_index("testings", "last_name", where: "first_name = 'john doe'")
-          assert connection.index_exists?("testings", "last_name")
+      def test_add_partial_index
+        skip("current adapter doesn't support partial indexes") unless supports_partial_index?
 
-          connection.remove_index("testings", "last_name")
-          assert_not connection.index_exists?("testings", "last_name")
+        connection.add_index("testings", "last_name", where: "first_name = 'john doe'")
+        assert connection.index_exists?("testings", "last_name")
+
+        connection.remove_index("testings", "last_name")
+        assert_not connection.index_exists?("testings", "last_name")
+      end
+
+      def test_add_index_with_included_column
+        skip("current adapter doesn't support include indexes") unless supports_index_include?
+
+        connection.add_index("testings", "last_name", include: :foo)
+        assert connection.index_exists?("testings", "last_name", include: :foo)
+
+        connection.remove_index("testings", "last_name")
+        assert_not connection.index_exists?("testings", "last_name")
+      end
+
+      def test_add_index_with_multiple_included_columns
+        skip("current adapter doesn't support include indexes") unless supports_index_include?
+
+        connection.add_index("testings", "last_name", include: [:foo, :bar])
+        assert connection.index_exists?("testings", "last_name", include: [:foo, :bar])
+
+        connection.remove_index("testings", "last_name")
+        assert_not connection.index_exists?("testings", "last_name")
+      end
+
+      def test_add_index_with_included_column_and_where_clause
+        skip("current adapter doesn't support include indexes") unless supports_index_include?
+
+        connection.add_index("testings", "last_name", include: :foo, where: "first_name = 'john doe'")
+        assert connection.index_exists?("testings", "last_name", include: :foo, where: "first_name = 'john doe'")
+
+        connection.remove_index("testings", "last_name")
+        assert_not connection.index_exists?("testings", "last_name", include: :foo, where: "first_name = 'john doe'")
+      end
+
+      def test_add_index_with_nulls_not_distinct_assert_exists_with_same_values
+        skip("current adapter doesn't support nulls not distinct") unless supports_nulls_not_distinct?
+
+        connection.add_index("testings", "last_name", nulls_not_distinct: true)
+        assert connection.index_exists?("testings", "last_name", nulls_not_distinct: true)
+      end
+
+      def test_add_index_with_nulls_not_distinct_assert_exists_with_different_values
+        skip("current adapter doesn't support nulls not distinct") unless supports_nulls_not_distinct?
+
+        connection.add_index("testings", "last_name", nulls_not_distinct: false)
+        assert_not connection.index_exists?("testings", "last_name", nulls_not_distinct: true)
+      end
+
+      if ActiveRecord::Base.lease_connection.supports_disabling_indexes?
+        def test_index_visibility_through_add_index
+          connection.add_index(:testings, :foo, enabled: false)
+
+          assert connection.index_exists?(:testings, :foo, enabled: false)
         end
 
-        def test_add_index_with_included_column
-          skip("current adapter doesn't support include indexes") unless supports_index_include?
+        def test_index_disabling_through_disable_index
+          connection.add_index(:testings, :foo)
+          connection.disable_index(:testings, "index_testings_on_foo")
 
-          connection.add_index("testings", "last_name", include: :foo)
-          assert connection.index_exists?("testings", "last_name", include: :foo)
-
-          connection.remove_index("testings", "last_name")
-          assert_not connection.index_exists?("testings", "last_name")
-        end
-
-        def test_add_index_with_multiple_included_columns
-          skip("current adapter doesn't support include indexes") unless supports_index_include?
-
-          connection.add_index("testings", "last_name", include: [:foo, :bar])
-          assert connection.index_exists?("testings", "last_name", include: [:foo, :bar])
-
-          connection.remove_index("testings", "last_name")
-          assert_not connection.index_exists?("testings", "last_name")
-        end
-
-        def test_add_index_with_included_column_and_where_clause
-          skip("current adapter doesn't support include indexes") unless supports_index_include?
-
-          connection.add_index("testings", "last_name", include: :foo, where: "first_name = 'john doe'")
-          assert connection.index_exists?("testings", "last_name", include: :foo, where: "first_name = 'john doe'")
-
-          connection.remove_index("testings", "last_name")
-          assert_not connection.index_exists?("testings", "last_name", include: :foo, where: "first_name = 'john doe'")
-        end
-
-        def test_add_index_with_nulls_not_distinct_assert_exists_with_same_values
-          skip("current adapter doesn't support nulls not distinct") unless supports_nulls_not_distinct?
-
-          connection.add_index("testings", "last_name", nulls_not_distinct: true)
-          assert connection.index_exists?("testings", "last_name", nulls_not_distinct: true)
-        end
-
-        def test_add_index_with_nulls_not_distinct_assert_exists_with_different_values
-          skip("current adapter doesn't support nulls not distinct") unless supports_nulls_not_distinct?
-
-          connection.add_index("testings", "last_name", nulls_not_distinct: false)
-          assert_not connection.index_exists?("testings", "last_name", nulls_not_distinct: true)
+          assert connection.index_exists?(:testings, :foo, enabled: false)
         end
       end
 
