@@ -194,7 +194,7 @@ class MigrationTest < ActiveRecord::TestCase
     error = assert_raises(ArgumentError) do
       connection.create_table(long_name)
     end
-    assert_equal "Table name '#{long_name}' is too long; the limit is #{name_limit} characters", error.message
+    assert_equal "Table name '#{long_name}' is too long \(#{long_name.length} characters\); the limit is #{name_limit} characters", error.message
 
     connection.create_table(short_name)
     assert connection.table_exists?(short_name)
@@ -461,6 +461,21 @@ class MigrationTest < ActiveRecord::TestCase
     assert_equal "hi mom!", migration.method_missing(:create_table)
   end
 
+  def test_respond_to_for_migration_method
+    migration_class = Class.new(ActiveRecord::Migration::Current) {
+      def connection
+        Class.new {
+          def create_table; end
+        }.new
+      end
+    }
+
+    migration_class.class_eval { undef_method :create_table }
+    # create_table is handled by method_missing, so respond_to? returns true.
+    assert migration_class.new.respond_to?(:create_table)
+    assert migration_class.respond_to?(:create_table)
+  end
+
   def test_add_table_with_decimals
     Person.lease_connection.drop_table :big_numbers rescue nil
 
@@ -1254,7 +1269,7 @@ if ActiveRecord::Base.lease_connection.supports_bulk_alter?
 
       assert_equal 8, columns.size
       [:name, :qualification, :experience].each { |s| assert_equal :string, column(s).type }
-      assert_equal "0", column(:age).default
+      assert_equal 0, column(:age).default
       assert_equal "This is a comment", column(:birthdate).comment
     end
 
