@@ -1,6 +1,7 @@
 # frozen_string_literal: true
 
 require "cases/helper"
+require "support/deprecated_associations_test_helpers"
 require "models/pirate"
 require "models/developer"
 require "models/ship"
@@ -15,6 +16,8 @@ require "models/pet"
 require "models/entry"
 require "models/message"
 require "models/cpk"
+require "models/car"
+require "models/dats"
 require "active_support/hash_with_indifferent_access"
 
 class TestNestedAttributesInGeneral < ActiveRecord::TestCase
@@ -1235,3 +1238,40 @@ class TestNestedAttributesForDelegatedType < ActiveRecord::TestCase
     assert_equal "Hello world!", @entry.entryable.subject
   end
 end
+
+class NestedAttributesForDeprecatedAssociationsTest < ActiveRecord::TestCase
+  include DeprecatedAssociationsTestHelpers
+
+  fixtures :cars
+
+  setup do
+    @model = DATS::Car
+    @car = @model.first
+    @tire_attributes = {}
+    @bulb_attributes = { "name" => "name for deprecated nested attributes" }
+  end
+
+  test "has_many" do
+    assert_not_deprecated_association(:tires) do
+      @car.tires_attributes = [@tire_attributes]
+    end
+
+    assert_deprecated_association(:deprecated_tires, context: context_for_method(:deprecated_tires_attributes=)) do
+      @car.deprecated_tires_attributes = [@tire_attributes]
+    end
+
+    assert @tire_attributes <= @car.deprecated_tires[0].attributes
+  end
+
+  test "has_one" do
+    assert_not_deprecated_association(:bulb) do
+      @car.bulb_attributes = @bulb_attributes
+    end
+
+    assert_deprecated_association(:deprecated_bulb, context: context_for_method(:deprecated_bulb_attributes=)) do
+      @car.deprecated_bulb_attributes = @bulb_attributes
+    end
+
+    assert @bulb_attributes <= @car.deprecated_bulb.attributes
+  end
+end
