@@ -361,6 +361,27 @@ class PersistenceTest < ActiveRecord::TestCase
     assert_raises(ArgumentError) { topic.increment! }
   end
 
+  def test_increment_new_record
+    topic = Topic.new
+
+    assert_no_queries do
+      assert_raises ActiveRecord::ActiveRecordError do
+        topic.increment!(:replies_count)
+      end
+    end
+  end
+
+  def test_increment_destroyed_record
+    topic = topics(:first)
+    topic.destroy
+
+    assert_no_queries do
+      assert_raises ActiveRecord::ActiveRecordError do
+        topic.increment!(:replies_count)
+      end
+    end
+  end
+
   def test_destroy_many
     clients = Client.find([2, 3])
 
@@ -477,6 +498,17 @@ class PersistenceTest < ActiveRecord::TestCase
     assert_equal %w{name}, client.changed
   end
 
+  def test_becomes_preserve_record_status
+    company = Company.new(name: "37signals")
+    client = company.becomes(Client)
+    assert_predicate client, :new_record?
+
+    company.save
+    client = company.becomes(Client)
+    assert_predicate client, :persisted?
+    assert_predicate client, :previously_new_record?
+  end
+
   def test_becomes_initializes_missing_attributes
     company = Company.new(name: "GrowingCompany")
 
@@ -1107,6 +1139,25 @@ class PersistenceTest < ActiveRecord::TestCase
     assert_not_predicate topic, :approved?
   end
 
+  def test_update_column_touch_option
+    topic = Topic.find(1)
+
+    assert_changes -> { topic.updated_at } do
+      travel(1.second) do
+        topic.update_column(:title, "super_title", touch: true)
+      end
+    end
+  end
+
+  def test_update_column_touch_option_with_specific_time
+    topic = Topic.find(1)
+    new_updated_at = Date.parse("2024-03-31 12:00:00")
+
+    assert_changes -> { topic.updated_at }, to: new_updated_at do
+      topic.update_column(:title, "super_title", touch: { time: new_updated_at })
+    end
+  end
+
   def test_update_column_should_not_use_setter_method
     dev = Developer.find(1)
     dev.instance_eval { def salary=(value); write_attribute(:salary, value * 2); end }
@@ -1198,6 +1249,53 @@ class PersistenceTest < ActiveRecord::TestCase
     assert_equal "Sebastian Topic", topic.title
   end
 
+  def test_update_columns_touch_option_updates_timestamps
+    topic = Topic.find(1)
+
+    assert_changes -> { topic.updated_at } do
+      travel(1.second) do
+        topic.update_columns(title: "super_title", touch: true)
+      end
+    end
+  end
+
+  def test_update_columns_touch_option_explicit_column_names
+    topic = Topic.find(1)
+
+    assert_changes -> { [topic.updated_at, topic.written_on] } do
+      travel(1.second) do
+        topic.update_columns(title: "super_title", touch: :written_on)
+      end
+    end
+  end
+
+  def test_update_columns_touch_option_not_overwrite_explicit_attribute
+    topic = Topic.find(1)
+    new_updated_at = Date.parse("2024-03-31 12:00:00")
+
+    assert_changes -> { topic.updated_at }, to: new_updated_at do
+      topic.update_columns(title: "super_title", updated_at: new_updated_at, touch: true)
+    end
+  end
+
+  def test_update_columns_touch_option_not_overwrite_explicit_attribute_with_string_key
+    topic = Topic.find(1)
+    new_updated_at = Date.parse("2024-03-31 12:00:00")
+
+    assert_changes -> { topic.updated_at }, to: new_updated_at do
+      topic.update_columns(title: "super_title", "updated_at" => new_updated_at, touch: true)
+    end
+  end
+
+  def test_update_columns_touch_option_with_specific_time
+    topic = Topic.find(1)
+    new_updated_at = Date.parse("2024-03-31 12:00:00")
+
+    assert_changes -> { topic.updated_at }, to: new_updated_at do
+      topic.update_columns(title: "super_title", touch: { time: new_updated_at })
+    end
+  end
+
   def test_update_columns_should_not_use_setter_method
     dev = Developer.find(1)
     dev.instance_eval { def salary=(value); write_attribute(:salary, value * 2); end }
@@ -1648,7 +1746,7 @@ class QueryConstraintsTest < ActiveRecord::TestCase
     assert_uses_query_constraints_on_reload(used_clothing_item, ["clothing_type", "color"])
   end
 
-  def test_child_keeps_parents_query_contraints_derived_from_composite_pk
+  def test_child_keeps_parents_query_constraints_derived_from_composite_pk
     assert_equal(["author_id", "id"], Cpk::BestSeller.query_constraints_list)
   end
 
