@@ -2,6 +2,7 @@
 
 require "pp"
 require "cases/helper"
+require "support/deprecated_associations_test_helpers.rb"
 require "models/tag"
 require "models/tagging"
 require "models/post"
@@ -19,7 +20,7 @@ require "models/contract"
 require "models/bird"
 require "models/car"
 require "models/engine"
-require "models/tyre"
+require "models/tire"
 require "models/minivan"
 require "models/possession"
 require "models/reader"
@@ -29,6 +30,7 @@ require "models/edge"
 require "models/wheel"
 require "models/subscriber"
 require "models/cpk"
+require "models/dats"
 
 class RelationTest < ActiveRecord::TestCase
   fixtures :authors, :author_addresses, :topics, :entrants, :developers, :people, :companies, :developers_projects, :accounts, :categories, :categorizations, :categories_posts, :posts, :comments, :tags, :taggings, :cars, :minivans, :cpk_orders
@@ -47,12 +49,12 @@ class RelationTest < ActiveRecord::TestCase
 
   def test_two_scopes_with_includes_should_not_drop_any_include
     # heat habtm cache
-    car = Car.incl_engines.incl_tyres.first
-    car.tyres.length
+    car = Car.incl_engines.incl_tires.first
+    car.tires.length
     car.engines.length
 
-    car = Car.incl_engines.incl_tyres.first
-    assert_no_queries { car.tyres.length }
+    car = Car.incl_engines.incl_tires.first
+    assert_no_queries { car.tires.length }
     assert_no_queries { car.engines.length }
   end
 
@@ -366,9 +368,23 @@ class RelationTest < ActiveRecord::TestCase
   end if current_adapter?(:PostgreSQLAdapter)
 
   def test_default_reverse_order_on_table_without_primary_key
-    assert_raises(ActiveRecord::IrreversibleOrderError) do
+    error = assert_raises(ActiveRecord::IrreversibleOrderError) do
       Edge.all.reverse_order
     end
+    assert_match(/Relation has no order values/, error.message)
+  end
+
+  def test_default_reverse_order_on_table_without_primary_key_with_implicit_order_column
+    ordered_edge = Class.new(Edge) do
+      self.implicit_order_column = "source_id"
+    end
+
+    ordered_edge.delete_all
+
+    edge_1 = ordered_edge.create!(source_id: 1, sink_id: 2)
+    edge_2 = ordered_edge.create!(source_id: 2, sink_id: 3)
+    assert_equal edge_1.source_id, ordered_edge.all.first.source_id
+    assert_equal edge_2.source_id, ordered_edge.all.reverse_order.first.source_id
   end
 
   def test_order_with_hash_and_symbol_generates_the_same_sql
@@ -1351,13 +1367,13 @@ class RelationTest < ActiveRecord::TestCase
   def test_create_with_block
     sparrow = Bird.create do |bird|
       bird.name = "sparrow"
-      bird.color = "grey"
+      bird.color = "gray"
     end
 
     assert_kind_of Bird, sparrow
     assert_predicate sparrow, :persisted?
     assert_equal "sparrow", sparrow.name
-    assert_equal "grey", sparrow.color
+    assert_equal "gray", sparrow.color
   end
 
   def test_create_bang_with_array
@@ -1758,7 +1774,7 @@ class RelationTest < ActiveRecord::TestCase
 
   def test_anonymous_extension
     relation = Post.where(author_id: 1).order("id ASC").extending do
-      def author
+      def author # rubocop:disable Lint/NestedMethodDefinition
         "lifo"
       end
     end
@@ -2540,3 +2556,229 @@ class CreateOrFindByWithinTransactions < ActiveRecord::TestCase
       end
   end
 end
+
+class DeprecatedAssociationsRelationSimpleTest < ActiveRecord::TestCase
+  include DeprecatedAssociationsTestHelpers
+
+  fixtures :cars
+
+  setup do
+    @model = DATS::Car
+  end
+
+  test "includes reports deprecated associations" do
+    assert_not_deprecated_association(:tires) do
+      @model.includes(:tires).to_a
+    end
+
+    assert_deprecated_association(:deprecated_tires, context: context_for_preload) do
+      @model.includes(:deprecated_tires).to_a
+    end
+  end
+
+  test "eager_load reports deprecated associations" do
+    assert_not_deprecated_association(:tires) do
+      @model.eager_load(:tires).to_a
+    end
+
+    assert_deprecated_association(:deprecated_tires, context: context_for_join) do
+      @model.eager_load(:deprecated_tires).to_a
+    end
+  end
+
+  test "preload reports deprecated associations" do
+    assert_not_deprecated_association(:tires) do
+      @model.preload(:tires).to_a
+    end
+
+    assert_deprecated_association(:deprecated_tires, context: context_for_preload) do
+      @model.preload(:deprecated_tires).to_a
+    end
+  end
+
+  test "extract_associated reports deprecated associations" do
+    assert_not_deprecated_association(:tires) do
+      @model.extract_associated(:tires).to_a
+    end
+
+    assert_deprecated_association(:deprecated_tires, context: context_for_preload) do
+      @model.extract_associated(:deprecated_tires).to_a
+    end
+  end
+
+  test "joins reports deprecated associations" do
+    assert_not_deprecated_association(:tires) do
+      @model.joins(:tires).to_a
+    end
+
+    assert_deprecated_association(:deprecated_tires, context: context_for_join) do
+      @model.joins(:deprecated_tires).to_a
+    end
+  end
+
+  test "left_outer_joins reports deprecated associations" do
+    assert_not_deprecated_association(:tires) do
+      @model.left_outer_joins(:tires).to_a
+    end
+
+    assert_deprecated_association(:deprecated_tires, context: context_for_join) do
+      @model.left_outer_joins(:deprecated_tires).to_a
+    end
+  end
+
+  test "left_joins reports deprecated associations" do
+    assert_not_deprecated_association(:tires) do
+      @model.left_joins(:tires).to_a
+    end
+
+    assert_deprecated_association(:deprecated_tires, context: context_for_join) do
+      @model.left_joins(:deprecated_tires).to_a
+    end
+  end
+
+  test "associated reports deprecated associations" do
+    assert_not_deprecated_association(:tires) do
+      @model.where.associated(:tires).to_a
+    end
+
+    assert_deprecated_association(:deprecated_tires, context: context_for_join) do
+      @model.where.associated(:deprecated_tires).to_a
+    end
+  end
+
+  test "missing reports deprecated associations" do
+    assert_not_deprecated_association(:tires) do
+      @model.where.missing(:tires).to_a
+    end
+
+    assert_deprecated_association(:deprecated_tires, context: context_for_join) do
+      @model.where.missing(:deprecated_tires).to_a
+    end
+  end
+end
+
+class DeprecatedAssociationsRelationComplexTest < ActiveRecord::TestCase
+  include DeprecatedAssociationsTestHelpers
+
+  fixtures :posts, :authors, :author_addresses
+
+  setup do
+    @model = DATS::Post
+  end
+
+  test "includes reports deprecated associations" do
+    assert_not_deprecated_association(:tires) do
+      @model.includes(:comments, author: :author_favorites).to_a
+    end
+
+    assert_deprecated_association(:deprecated_comments, context: context_for_preload) do
+      @model.includes(:deprecated_comments, author: :deprecated_author_favorites).to_a
+    end
+
+    assert_deprecated_association(:deprecated_author_favorites, model: DATS::Author, context: context_for_preload) do
+      @model.includes(:deprecated_comments, author: :deprecated_author_favorites).to_a
+    end
+  end
+
+  test "eager_load reports deprecated associations" do
+    assert_not_deprecated_association(:tires) do
+      @model.eager_load(:comments, author: :author_favorites).to_a
+    end
+
+    assert_deprecated_association(:deprecated_comments, context: context_for_join) do
+      @model.eager_load(:deprecated_comments, author: :deprecated_author_favorites).to_a
+    end
+
+    assert_deprecated_association(:deprecated_author_favorites, model: DATS::Author, context: context_for_join) do
+      @model.eager_load(:deprecated_comments, author: :deprecated_author_favorites).to_a
+    end
+  end
+
+  test "preload reports deprecated associations" do
+    assert_not_deprecated_association(:tires) do
+      @model.preload(:comments, author: :author_favorites).to_a
+    end
+
+    assert_deprecated_association(:deprecated_comments, context: context_for_preload) do
+      @model.preload(:deprecated_comments, author: :deprecated_author_favorites).to_a
+    end
+
+    assert_deprecated_association(:deprecated_author_favorites, model: DATS::Author, context: context_for_preload) do
+      @model.preload(:deprecated_comments, author: :deprecated_author_favorites).to_a
+    end
+  end
+
+  test "joins reports deprecated associations" do
+    assert_not_deprecated_association(:tires) do
+      @model.joins(:comments, author: :author_favorites).to_a
+    end
+
+    assert_deprecated_association(:deprecated_comments, context: context_for_join) do
+      @model.joins(:deprecated_comments, author: :deprecated_author_favorites).to_a
+    end
+
+    assert_deprecated_association(:deprecated_author_favorites, model: DATS::Author, context: context_for_join) do
+      @model.joins(:deprecated_comments, author: :deprecated_author_favorites).to_a
+    end
+  end
+
+  test "left_outer_joins reports deprecated associations" do
+    assert_not_deprecated_association(:tires) do
+      @model.left_outer_joins(:comments, author: :author_favorites).to_a
+    end
+
+    assert_deprecated_association(:deprecated_comments, context: context_for_join) do
+      @model.left_outer_joins(:deprecated_comments, author: :deprecated_author_favorites).to_a
+    end
+
+    assert_deprecated_association(:deprecated_author_favorites, model: DATS::Author, context: context_for_join) do
+      @model.left_outer_joins(:deprecated_comments, author: :deprecated_author_favorites).to_a
+    end
+  end
+
+  test "left_joins reports deprecated associations" do
+    assert_not_deprecated_association(:tires) do
+      @model.left_joins(:comments, author: :author_favorites).to_a
+    end
+
+    assert_deprecated_association(:deprecated_comments, context: context_for_join) do
+      @model.left_joins(:deprecated_comments, author: :deprecated_author_favorites).to_a
+    end
+
+    assert_deprecated_association(:deprecated_author_favorites, model: DATS::Author, context: context_for_join) do
+      @model.left_joins(:deprecated_comments, author: :deprecated_author_favorites).to_a
+    end
+  end
+
+  test "associated reports deprecated associations" do
+    assert_not_deprecated_association(:tires) do
+      @model.where.associated(:comments, :author_favorites).to_a
+    end
+
+    assert_deprecated_association(:deprecated_comments, context: context_for_join) do
+      @model.where.associated(:deprecated_comments, :author_favorites).to_a
+    end
+
+    assert_deprecated_association(:deprecated_author_favorites, model: DATS::Author, context: context_for_through(:author_favorites)) do
+      # :author_favorites is correct, this one is a has_many through and
+      # :deprecated_author_favorites is a nested one.
+      @model.where.associated(:deprecated_comments, :author_favorites).to_a
+    end
+  end
+
+  test "missing reports deprecated associations" do
+    assert_not_deprecated_association(:tires) do
+      @model.where.missing(:comments, :author_favorites).to_a
+    end
+
+    assert_deprecated_association(:deprecated_comments, context: context_for_join) do
+      @model.where.missing(:deprecated_comments, :author_favorites).to_a
+    end
+
+    assert_deprecated_association(:deprecated_author_favorites, model: DATS::Author, context: context_for_through(:author_favorites)) do
+      # :author_favorites is correct, this one is a has_many through and
+      # :deprecated_author_favorites is a nested one we get a notification for.
+      @model.where.missing(:deprecated_comments, :author_favorites).to_a
+    end
+  end
+end
