@@ -30,6 +30,10 @@ class Developer < ActiveRecord::Base
     end
   end
 
+  def self.target
+    :__target__ # Used by delegation_test.rb
+  end
+
   belongs_to :mentor
   belongs_to :strict_loading_mentor, strict_loading: true, foreign_key: :mentor_id, class_name: "Mentor"
   belongs_to :strict_loading_off_mentor, strict_loading: false, foreign_key: :mentor_id, class_name: "Mentor"
@@ -131,6 +135,8 @@ end
 class AuditLog < ActiveRecord::Base
   belongs_to :developer, validate: true
   belongs_to :unvalidated_developer, class_name: "Developer"
+
+  self.attributes_for_inspect = [:id, :message]
 end
 
 class AuditLogRequired < ActiveRecord::Base
@@ -369,3 +375,14 @@ class ColumnNamesCachedDeveloper < ActiveRecord::Base
   self.table_name = "developers"
   self.ignored_columns += ["name"] if column_names.include?("name")
 end
+
+class AuditRequiredDeveloper < ActiveRecord::Base
+  self.table_name = "developers"
+  has_many :required_audit_logs, class_name: "AuditLogRequired"
+end
+
+class OnlyColumnsDeveloper < ActiveRecord::Base
+  self.table_name = "developers"
+  self.only_columns = %w[name salary firm_id mentor_id]
+  has_many :required_audit_logs, class_name: "AuditLogRequired"
+end
