@@ -1,9 +1,12 @@
 # frozen_string_literal: true
 
 class Membership < ActiveRecord::Base
-  enum type: %i(Membership CurrentMembership SuperMembership SelectedMembership TenantMembership)
+  enum :type, %i(Membership CurrentMembership SuperMembership SelectedMembership TenantMembership)
   belongs_to :member
   belongs_to :club
+  has_one :sponsor, through: :club
+
+  belongs_to :simple_member, foreign_key: "member_id"
 end
 
 class CurrentMembership < Membership
