@@ -139,6 +139,7 @@ ActiveRecord::Schema.define do
     t.column :font_size, :integer, **default_zero
     t.column :difficulty, :integer, **default_zero
     t.column :cover, :string, default: "hard"
+    t.column :symbol_status, :string, default: "proposed"
     t.string :isbn
     t.string :external_id
     t.column :original_name, :string
@@ -201,7 +202,7 @@ ActiveRecord::Schema.define do
     t.integer :wheels_count, default: 0, null: false
     t.datetime :wheels_owned_at
     t.integer :bulbs_count
-    t.integer :custom_tyres_count
+    t.integer :custom_tires_count
     t.column :lock_version, :integer, null: false, default: 0
     t.timestamps null: false
   end
@@ -438,6 +439,10 @@ ActiveRecord::Schema.define do
         t.index "(CONCAT_WS(`firm_name`, `name`, _utf8mb4' '))", name: "full_name_index"
       end
     end
+
+    if supports_disabling_indexes?
+      t.index [:firm_id, :client_of], name: "company_disabled_index", enabled: false
+    end
   end
 
   create_table :content, force: true do |t|
@@ -599,6 +604,11 @@ ActiveRecord::Schema.define do
     t.references :car, index: false
   end
 
+  create_table :enrollments, force: true do |t|
+    t.integer  :program_id
+    t.integer  :member_id
+  end
+
   create_table :entrants, force: true do |t|
     t.string  :name, null: false
     t.integer :course_id, null: false
@@ -1029,6 +1039,16 @@ ActiveRecord::Schema.define do
     t.decimal :discounted_price
   end
 
+  create_table :program_offerings, force: true do |t|
+    t.integer  :club_id
+    t.integer  :program_id
+    t.datetime :start_date
+  end
+
+  create_table :programs, force: true do |t|
+    t.string   :name
+  end
+
   add_check_constraint :products, "price > discounted_price", name: "products_price_check"
 
   create_table :product_types, force: true do |t|
@@ -1258,7 +1278,7 @@ ActiveRecord::Schema.define do
     t.float :pitch
   end
 
-  create_table :tyres, force: true do |t|
+  create_table :tires, force: true do |t|
     t.integer :car_id
   end
 
