@@ -20,7 +20,7 @@ module ARTest
 
   def self.connect
     ActiveRecord.async_query_executor = :global_thread_pool
-    puts "Using #{connection_name}"
+    puts "Using #{connection_name}#{ " with prepared statements" if ENV["MYSQL_PREPARED_STATEMENTS"]}"
 
     if ENV["BUILDKITE"]
       ActiveRecord::Base.logger = nil
@@ -32,7 +32,7 @@ module ARTest
     ActiveRecord::Base.establish_connection :arunit
     ARUnit2Model.establish_connection :arunit2
 
-    arunit_adapter = ActiveRecord::Base.connection.pool.db_config.adapter
+    arunit_adapter = ActiveRecord::Base.lease_connection.pool.db_config.adapter
 
     unless connection_name.include?(arunit_adapter)
       raise ArgumentError, "The connection name did not match the adapter name. Connection name is '#{connection_name}' and the adapter name is '#{arunit_adapter}'."
