@@ -21,21 +21,16 @@ class ActiveStorage::Service::ConfiguratorTest < ActiveSupport::TestCase
     end
   end
 
-  test "azure service is deprecated" do
-    msg = <<~MSG.squish
-      `ActiveStorage::Service::AzureStorageService` is deprecated and will be
-      removed in Rails 8.1.
-      Please try the `azure-blob` gem instead.
-      This gem is not maintained by the Rails team, so please test your applications before deploying to production.
-    MSG
+  test "inspect attributes" do
+    config = {
+      local: { service: "Disk", root: "/tmp/active_storage_configurator_test" },
+      tmp: { service: "Disk", root: "/tmp/active_storage_configurator_test_tmp" },
+    }
 
-    assert_deprecated(msg, ActiveStorage.deprecator) do
-      ActiveStorage::Service::Configurator.build(:azure, azure: {
-        service: "AzureStorage",
-        storage_account_name: "test_account",
-        storage_access_key: Base64.encode64("test_access_key").strip,
-        container: "container"
-      })
-    end
+    configurator = ActiveStorage::Service::Configurator.new(config)
+    assert_match(/#<ActiveStorage::Service::Configurator configurations=\[:local, :tmp\]>/, configurator.inspect)
+
+    configurator = ActiveStorage::Service::Configurator.new({})
+    assert_match(/#<ActiveStorage::Service::Configurator>/, configurator.inspect)
   end
 end
