@@ -135,6 +135,14 @@ module ActiveSupport
       ], actual_tokens
     end
 
+    # This happens when a template is multiline and no
+    # ERB tags are used on the current line.
+    def test_plain_without_tags
+      source = " @post.title\n"
+      actual_tokens = tokenize source
+      assert_equal [[:PLAIN, " @post.title"]], actual_tokens
+    end
+
     def test_multibyte_characters_start
       source = "こんにちは<%= name %>"
       actual_tokens = tokenize source
