@@ -253,10 +253,18 @@ class RangeTest < ActiveSupport::TestCase
     end
   end
 
-  def test_step_on_time_with_zone
-    twz = ActiveSupport::TimeWithZone.new(nil, ActiveSupport::TimeZone["Eastern Time (US & Canada)"], Time.utc(2006, 11, 28, 10, 30))
-    assert_raises TypeError do
-      ((twz - 1.hour)..twz).step(1) { }
+  if RUBY_VERSION < "3.4"
+    def test_step_on_time_with_zone
+      twz = ActiveSupport::TimeWithZone.new(nil, ActiveSupport::TimeZone["Eastern Time (US & Canada)"], Time.utc(2006, 11, 28, 10, 30))
+      assert_raises TypeError do
+        ((twz - 1.hour)..twz).step(1) { }
+      end
+    end
+  else
+    def test_step_on_time_with_zone
+      twz = ActiveSupport::TimeWithZone.new(nil, ActiveSupport::TimeZone["Eastern Time (US & Canada)"], Time.utc(2006, 11, 28, 10, 30))
+
+      assert_equal [twz, twz + 15.minutes, twz + 30.minutes], (twz..).step(15.minutes).first(3)
     end
   end
 
