@@ -12,13 +12,19 @@ gemfile(true) do
   gem "sqlite3"
 end
 
-require "active_record"
+require "active_record/railtie"
 require "minitest/autorun"
-require "logger"
 
 # This connection will do for database-independent bug reports.
-ActiveRecord::Base.establish_connection(adapter: "sqlite3", database: ":memory:")
-ActiveRecord::Base.logger = Logger.new(STDOUT)
+ENV["DATABASE_URL"] = "sqlite3::memory:"
+
+class TestApp < Rails::Application
+  config.load_defaults Rails::VERSION::STRING.to_f
+  config.eager_load = false
+  config.logger = Logger.new($stdout)
+  config.secret_key_base = "secret_key_base"
+end
+Rails.application.initialize!
 
 ActiveRecord::Schema.define do
   create_table :payments, force: true do |t|
