@@ -33,8 +33,11 @@ class FullStackConsoleTest < ActiveSupport::TestCase
   end
 
   def spawn_console(options, wait_for_prompt: true, env: {})
+    # Test should not depend on user's irbrc file
+    home_tmp_dir = Dir.mktmpdir
+
     pid = Process.spawn(
-      { "TERM" => "dumb" }.merge(env),
+      { "TERM" => "dumb", "HOME" => home_tmp_dir }.merge(env),
       "#{app_path}/bin/rails console #{options}",
       in: @replica, out: @replica, err: @replica
     )
@@ -44,6 +47,8 @@ class FullStackConsoleTest < ActiveSupport::TestCase
     end
 
     pid
+  ensure
+    FileUtils.remove_entry(home_tmp_dir)
   end
 
   def test_sandbox
@@ -114,7 +119,7 @@ class FullStackConsoleTest < ActiveSupport::TestCase
     options = "-e test -- --verbose"
     spawn_console(options)
 
-    write_prompt "a = 1", "a = 1", prompt: "app-template(test)>"
+    write_prompt "a = 1", "a = 1", prompt: "app-template(test):"
   end
 
   def test_prompt_allows_changing_irb_name
@@ -122,7 +127,7 @@ class FullStackConsoleTest < ActiveSupport::TestCase
     spawn_console(options)
 
     write_prompt "conf.irb_name = 'foo'"
-    write_prompt "a = 1", "a = 1", prompt: "foo(test)>"
+    write_prompt "a = 1", "a = 1", prompt: "foo(test):"
     @primary.puts "quit"
   end
 
@@ -139,21 +144,21 @@ class FullStackConsoleTest < ActiveSupport::TestCase
     options = "-e production"
     spawn_console(options)
 
-    write_prompt "123", prompt: "app-template(prod)>"
+    write_prompt "123", prompt: "app-template(prod):"
   end
 
   def test_development_console_prompt
     options = "-e development"
     spawn_console(options)
 
-    write_prompt "123", prompt: "app-template(dev)> "
+    write_prompt "123", prompt: "app-template(dev):"
   end
 
   def test_test_console_prompt
     options = "-e test"
     spawn_console(options)
 
-    write_prompt "123", prompt: "app-template(test)> "
+    write_prompt "123", prompt: "app-template(test):"
   end
 
   def test_helper_helper_method
@@ -247,7 +252,7 @@ class FullStackConsoleTest < ActiveSupport::TestCase
     options = "-e test"
     spawn_console(options, env: { "IRBRC" => irbrc.path })
 
-    write_prompt "123", prompt: "jarretts-irb(test)"
+    write_prompt "123", prompt: "jarretts-irb(test):002> "
   ensure
     File.unlink(irbrc)
   end
