@@ -258,6 +258,7 @@ module ApplicationTests
           end
         end
       end
+
       test "db:create works when schema cache exists and database does not exist" do
         use_postgresql
 
@@ -485,7 +486,7 @@ module ApplicationTests
             f.puts <<-YAML
             default: &default
               adapter: sqlite3
-              pool: 5
+              max_connections: 5
               timeout: 5000
               variables:
                 statement_timeout: 1000
@@ -507,7 +508,7 @@ module ApplicationTests
             f.puts <<-YAML
             default: &default
               adapter: sqlite3
-              pool: 5
+              max_connections: 5
               timeout: 5000
               variables:
                 statement_timeout: 1000
