@@ -47,7 +47,6 @@ class Rails::Command::MiddlewareTest < ActiveSupport::TestCase
       "ActionDispatch::Session::CookieStore",
       "ActionDispatch::Flash",
       "ActionDispatch::ContentSecurityPolicy::Middleware",
-      "ActionDispatch::PermissionsPolicy::Middleware",
       "Rack::Head",
       "Rack::ConditionalGet",
       "Rack::ETag",
@@ -85,7 +84,6 @@ class Rails::Command::MiddlewareTest < ActiveSupport::TestCase
       "ActionDispatch::Session::CookieStore",
       "ActionDispatch::Flash",
       "ActionDispatch::ContentSecurityPolicy::Middleware",
-      "ActionDispatch::PermissionsPolicy::Middleware",
       "Rack::Head",
       "Rack::ConditionalGet",
       "Rack::ETag",
@@ -219,6 +217,13 @@ class Rails::Command::MiddlewareTest < ActiveSupport::TestCase
     assert_equal [{ redirect: { host: "example.com" }, ssl_default_redirect_status: 308 }], Rails.application.middleware[1].args
   end
 
+  test "ActionDispatch::PermissionsPolicy::MiddlewareStack is included if permissions_policy set" do
+    add_to_config "config.permissions_policy { ActionDispatch::PermissionsPolicy.new }"
+    boot!
+
+    assert_includes middleware, "ActionDispatch::PermissionsPolicy::Middleware"
+  end
+
   test "removing Active Record omits its middleware" do
     use_frameworks []
     boot!
