@@ -109,6 +109,9 @@ class Releaser < Rake::TaskLib
       end
     end
 
+    desc "Update version of the frameworks"
+    task update_versions: FRAMEWORKS.map { |f| "#{f}:update_versions" } + ["rails:update_versions"]
+
     desc "Build gem files for all projects"
     task build: FRAMEWORKS.map { |f| "#{f}:build" } + ["rails:build"]
 
@@ -187,7 +190,7 @@ class Releaser < Rake::TaskLib
   end
 
   def npm_tag
-    pre_release? ? "pre" : "8-0-stable"
+    pre_release? ? "pre" : "latest"
   end
 
   # This "npm-ifies" the current version number
